summaryrefslogtreecommitdiff
path: root/docs/sphinx/gnuradio_sphinx.py
diff options
context:
space:
mode:
authorTom Rondeau <trondeau@vt.edu>2013-03-17 12:24:38 -0400
committerTom Rondeau <trondeau@vt.edu>2013-03-17 15:40:32 -0400
commitd4f6b86a9bdea09c2c158b9982559a727f8c6a0b (patch)
tree60b452d387bd494b461ee78b2b0faec1fbf6e5fe /docs/sphinx/gnuradio_sphinx.py
parentee2b700f72503d6e7f62adbfb7dff9997b9cb003 (diff)
blocks: converting references to vector source/sink, null source/sink, nop, copy, head, skiphead, vector_map, and annotator blocks to use gr-blocks.
Diffstat (limited to 'docs/sphinx/gnuradio_sphinx.py')
-rw-r--r--docs/sphinx/gnuradio_sphinx.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/docs/sphinx/gnuradio_sphinx.py b/docs/sphinx/gnuradio_sphinx.py
index e8ca867f8c..9955bf7317 100644
--- a/docs/sphinx/gnuradio_sphinx.py
+++ b/docs/sphinx/gnuradio_sphinx.py
@@ -113,8 +113,8 @@ class OldBlockDocumenter(FunctionDocumenter):
"""
Specialized Documenter subclass for gnuradio blocks.
- It merges together the documentation for the generator function (e.g. gr.head)
- with the wrapped sptr (e.g. gr.gr_head_sptr) to keep the documentation
+ It merges together the documentation for the generator function (e.g. blocks.head)
+ with the wrapped sptr (e.g. gr::blocks::head::sptr) to keep the documentation
tidier.
"""
objtype = 'oldblock'